## START: Set by rpmautospec
## (rpmautospec version 0.6.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           plantuml
Version:        1.2024.5
Release:        %autorelease
Epoch:          1
Summary:        Program to generate UML diagram from a text description

License:        LGPL-3.0-or-later
URL:            http://plantuml.com/
Source:         https://github.com/%{name}/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildArch:      noarch
ExclusiveArch:  %{java_arches} noarch

BuildRequires:  ant
BuildRequires:  help2man
BuildRequires:  javapackages-local

Requires:       java >= 1.8.0
# Explicit requires for javapackages-tools since plantuml script
# uses /usr/share/java-utils/java-functions
Requires:       javapackages-tools

%description
PlantUML is a program allowing to draw UML diagrams, using a simple
and human readable text description. It is extremely useful for code
documenting, sketching project architecture during team conversations
and so on.

PlantUML supports the following diagram types
  - sequence diagram
  - use case diagram
  - class diagram
  - activity diagram
  - component diagram
  - state diagram

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%autosetup
# Don't set Class-Path when building jar
sed --in-place '/<attribute name="Class-Path"/d' build.xml


%build
# Encoding needs to be set to UTF-8 for f38 and epel builds
%if 0%{?fedora} < 39 || 0%{?rhel}
export ANT_OPTS=-Dfile.encoding=UTF-8
%endif
ant

# build javadoc
export CLASSPATH=$(build-classpath ant):plantuml.jar
%javadoc -source 1.8 -encoding UTF-8 -Xdoclint:none -d javadoc $(find src -name "*.java") -windowtitle "PlantUML %{version}"

%install
# Set jar location
%mvn_file net.sourceforge.%{name}:%{name} %{name}
# Configure maven depmap
%mvn_artifact net.sourceforge.%{name}:%{name}:%{version} %{name}.jar
%mvn_install -J javadoc

%jpackage_script net.sourceforge.plantuml.Run "" "" plantuml plantuml true

# Build man page
install -d "%{buildroot}%{_mandir}/man1"
help2man --help-option='-h' --version-option='--version' --no-info --output='%{buildroot}%{_mandir}/man1/plantuml.1' "java -jar plantuml.jar"

%files -f .mfiles
%{_bindir}/plantuml
%doc README.md
%{_mandir}/man1/plantuml.1*
%license COPYING plantuml-lgpl/lgpl-license.txt

%files javadoc -f .mfiles-javadoc
%doc README.md
%license COPYING plantuml-lgpl/lgpl-license.txt

%changelog
## START: Generated by rpmautospec
* Mon May 27 2024 blinxen <h-k-81@hotmail.com> - 1:1.2024.5-1
- Update to version 1.2024.5 (rhbz#2283523)

* Sun Apr 14 2024 blinxen <h-k-81@hotmail.com> - 1:1.2024.4-2
- Update to version 1.2024.4 (rhbz#2273825)

* Tue Feb 27 2024 Jiri Vanek <jvanek@redhat.com> - 1:1.2024.3-3
- Rebuilt for java-21-openjdk as system jdk

* Sun Feb 18 2024 blinxen <h-k-81@hotmail.com> - 1:1.2024.3-1
- Update to version 1.2024.0 (rhbz#2263433)

* Sun Feb 04 2024 blinxen <h-k-81@hotmail.com> - 1:1.2024.0-6
- Remove not used files

* Sun Feb 04 2024 blinxen <h-k-81@hotmail.com> - 1:1.2024.0-5
- Fix f38 and epel builds by setting file encoding to UTF-8

* Sat Feb 03 2024 blinxen <h-k-81@hotmail.com> - 1:1.2024.0-4
- Patch out Class-Path attribute in build.xml See
  https://docs.fedoraproject.org/en-US/packaging-
  guidelines/Java/#_no_class_path_in_manifest_mf

* Sat Feb 03 2024 blinxen <h-k-81@hotmail.com> - 1:1.2024.0-3
- No need to include our own build.xml since latest upstream release
  includes it

* Sat Feb 03 2024 blinxen <h-k-81@hotmail.com> - 1:1.2024.0-2
- Build man page with help2man

* Sat Feb 03 2024 blinxen <h-k-81@hotmail.com> - 1:1.2024.0-1
- Update to version 1.2024.0 (rhbz#2262345)

* Thu Jan 25 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2023.13-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2023.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Thu Jan 04 2024 blinxen <h-k-81@hotmail.com> - 1:1.2023.13-1
- Update to version 1.2023.13 (rhbz#2254471)

* Sat Oct 21 2023 blinxen <h-k-81@hotmail.com> - 1:1.2023.12-1
- Update to version 1.2023.12 (rhbz#2245437)

* Sat Sep 23 2023 blinxen <h-k-81@hotmail.com> - 1:1.2023.11-1
- Update to version 1.2023.11 (rhbz#2232105)

* Fri Sep 22 2023 blinxen <h-k-81@hotmail.com> - 1:1.2023.7-4
- Migrate license specification to SPDX

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2023.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu May 18 2023 Sandipan Roy <bytehackr@fedoraproject.org> - 1:1.2023.7-1
- Updated version to 1.2023.7
- rhbz#2173392

* Wed Feb 22 2023 Sandipan Roy <bytehackr@fedoraproject.org> - 1:1.2023.1-1
- Updated version to 1.2023.1
- (bug #2151362)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2022.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sat Aug 20 2022 Sandipan Roy <bytehackr@fedoraproject.org> - 1:1.2022.6-1
- Updated version to 1.2022.6

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2022.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri Jul 08 2022 Jiri Vanek <jvanek@redhat.com> - 1:1.2022.5-2
- Rebuilt for Drop i686 JDKs

* Mon May 16 2022 Sandipan Roy <bytehackr@fedoraproject.org> - 1:1.2022.5-1
- Updated version to 1.2022.5
- Added fix for rhbz#2086392

* Mon Apr 18 2022 Sandipan Roy <bytehackr@fedoraproject.org> - 1:1.2022.4-1
- Updated version to 1.2022.4
- Added fix for rhbz#2076162
- Added fix for rhbz#2076163

* Mon Mar 07 2022 Sandipan Roy <bytehackr@fedoraproject.org> - 1:1.2022.2-1
- Updated version to 1.2022.2

* Sat Feb 05 2022 Jiri Vanek <jvanek@redhat.com> - 1:1.2021.16-3
- Rebuilt for java-17-openjdk as system jdk

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2021.16-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Dec 29 2021 Sandipan Roy <bytehackr@fedoraproject.org> - 1:1.2021.16-1
- Updated version to 1.2021.16

* Tue Jul 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2021.0-3
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2021.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jan 20 2021 James Davidson <james@greycastle.net> - 1:1.2021.0-1
- Update to 1.2021.0

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2019.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jul 23 2020 Fabio Valentini <decathorpe@gmail.com> - 1:1.2019.1-5
- Fix javadoc generation with Java 11.

* Sat Jul 11 2020 Jiri Vanek <jvanek@redhat.com> - 1:1.2019.1-4
- Rebuilt for JDK-11, see https://fedoraproject.org/wiki/Changes/Java11

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2019.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.2019.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Wed Feb 13 2019 Jan Safranek <jsafrane@redhat.com> - 1.2019.1-1
- Update to 1.2019.1
- Introduce Epoch, upstream versioning schema changed.

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 8033-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Aug 31 2018 Severin Gehwolf <sgehwolf@redhat.com> - 8033-9
- Add explicit requirement for javapackages-tools for plantuml script.
  See RHBZ#1600426.

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 8033-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 8033-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 8033-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 8033-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 8033-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Nov 26 2015 gil cattaneo <puntogil@libero.it> 8033-3
- edited javadoc task

* Thu Nov 26 2015 gil cattaneo <puntogil@libero.it> 8033-2
- fix README line ending

* Thu Nov 26 2015 gil cattaneo <puntogil@libero.it> 8033-1
- update to 8033
- minor changes to adapt to current guideline
- resolve some rpmlint problems
- introduce license macro
- fix java8doc doclint problems
- add maven metadata

* Mon Jun 22 2015 Jan Safranek <jsafrane@redhat.com> - 8027-1
- Update to ver. 8027

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 8020-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Mar  6 2015 Jan Safranek <jsafrane@redhat.com> - 8020-1
- Update to ver. 8020

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7992-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Feb 18 2014 Jan Safranek <jsafrane@redhat.com> - 7992-1
- Update to ver. 7992

* Thu Aug 29 2013 Jan Safranek <jsafrane@redhat.com> - 7978-1
- Update to ver. 7978

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7951-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7951-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Jan 22 2013 Jan Safranek <jsafrane@redhat.com> - 7951-1
- Update to ver. 7951
- Added README and COPYING

* Mon Jan 21 2013 Jan Safranek <jsafrane@redhat.com> - 7950-1
- Update to ver. 7950
- Use plantuml-gpl as source tarball to get source package without bundled
  libraries
  -> use ant
  -> use LGPLv3+ license

* Thu Dec  6 2012 Jan Safranek <jsafrane@redhat.com> - 7943-1
- Package created

## END: Generated by rpmautospec
